The `ggseg_3datlas` class is a subclass of [`data.frame`][base::data.frame()],
created in order to have different default behaviour. It heavily relies on
the "tibble" [`tbl_df`][tibble::tibble()].
[tidyverse](https://www.tidyverse.org/packages/), including
[dplyr](http://dplyr.tidyverse.org/),
[ggplot2](http://ggplot2.tidyverse.org/),
[tidyr](http://tidyr.tidyverse.org/), and
[readr](http://readr.tidyverse.org/).
Usage
as_ggseg3d_atlas(x, return = FALSE)
Value
an object of class 'ggseg3d_atlas'. A nested tibble of different
brain surface shapes, hemispheres and tri-surface mesh information
for different brain regions in a specific atlas.
Arguments
x
data.frame to be made a ggseg-atlas
return
return logical
Properties of `ggseg3d_atlas`
Objects of class `ggseg3d_atlas` have:
* A `class` attribute of `c("ggseg3d_atlas", "tbl_df", "tbl", "data.frame")`.
* A base type of `"list"`, where each element of the list has the same
[NROW()].
* A lot of this script and its functions are taken from the
[`tibble`][tibble::tibble()]-package