| pan_camera | R Documentation |
Sets the camera position for a ggseg3d widget or ggsegray rgl scene to standard anatomical views or custom positions.
pan_camera(p, camera)
p |
A 'ggseg3d' widget or 'ggsegray' rgl object. |
camera |
string, list, or numeric vector. Camera position preset name, custom eye position list, or 'c(x, y, z)' for rgl. Available camera presets:
|
The input object (modified), for piping.
## Not run:
ggseg3d() |> pan_camera("right lateral")
ggsegray(atlas = dk(), hemisphere = "left") |>
pan_camera("left lateral")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.