Learn R Programming

ggseg3d (version 1.6.3)

remove_axes: Remove axis information from ggseg3d plot

Description

When publishing data visualisation in 3d mesh plots in general the axes are not important, at least they are not for ggseg3d, where the axis values are arbitrary.

Usage

remove_axes(p)

Value

plotly object without axes

Arguments

p

plotly object

Examples

Run this code
library(magrittr)
ggseg3d() %>%
   remove_axes()

Run the code above in your browser using DataLab