Uses orthographic projection instead of perspective. This eliminates perspective distortion and ensures consistent sizing across all views.
Examples
ggseg3d() |>
set_orthographic()
Uses orthographic projection instead of perspective. This eliminates perspective distortion and ensures consistent sizing across all views.
ggseg3d() |>
set_orthographic()