Given a ggseg_atlas with vertices column and a brain mesh, creates a label vector for each mesh vertex based on which region it belongs to.
vertices_to_labels(atlas_data, n_vertices, na_label = NA_character_)Character vector of labels, one per mesh vertex
Data frame with region and vertices columns
Number of vertices in the mesh
Label for vertices not in any region