powered by
The default position for plotly mesh plots are not satisfying for brain plots. This convenience function can pan the camera to lateral or medial view, or to custom made views if you are plotly savvy.
pan_camera(p, camera, aspectratio = 1)
plotly object
string or list.
camera aspect ratio
library(dplyr) ggseg3d() %>% pan_camera("right lateral")
Run the code above in your browser using DataLab