powered by
When publishing data visualisation in 3d mesh plots in general the axes are not important, at least they are not for ggseg3d, where the axis values are arbitrary.
remove_axes(p)
plotly object without axes
plotly object
library(magrittr) ggseg3d() %>% remove_axes()
Run the code above in your browser using DataLab