Adds coloured outlines around brain regions. This is useful for highlighting region boundaries in figures. Works with both htmlwidget (`ggseg3d`) and rgl (`ggsegray`) objects. For rgl, edges must have been computed at creation time via `edge_by`.
Examples
if (FALSE) { # \dontrun{
ggseg3d(hemisphere = "left", edge_by = "region") |>
set_edges("black") |>
pan_camera("left lateral")
ggsegray(hemisphere = "left", edge_by = "region") |>
set_edges("red", width = 2) |>
pan_camera("left lateral")
} # }