Learn R Programming

ggseg3d (version 2.0.0)

set_flat_shading: Enable flat shading for ggseg3d plot

Description

Disables lighting effects to show colors exactly as specified. Useful for screenshots where accurate color reproduction is needed, such as atlas creation pipelines that extract contours from images.

Usage

set_flat_shading(p, flat = TRUE)

Value

ggseg3d widget object with updated shading

Arguments

p

ggseg3d widget object

flat

logical. Enable flat shading (default: TRUE)

Examples

Run this code
if (FALSE) {
ggseg3d() |>
  set_flat_shading()
}

Run the code above in your browser using DataLab