set_flat_shading: Enable flat shading for ggseg3d plot
Description
Disables lighting effects to show colors exactly as specified.
Useful for screenshots where accurate color reproduction is needed,
such as atlas creation pipelines that extract contours from images.