Given a ggseg_atlas with vertices column and a brain mesh, creates a color vector for each mesh vertex based on which region it belongs to.
vertices_to_colors(atlas_data, n_vertices, na_colour = "#CCCCCC")Character vector of colors, one per mesh vertex
Data frame with region, colour, and vertices columns
Number of vertices in the mesh
Color for vertices not in any region